@@ -25,7 +25,7 @@
  * list of people on the gedit Team.
  * See the ChangeLog files for a list of changes.
  *
- * $Id: gedit-file-chooser-dialog.c 5659 2007-06-28 08:36:12Z pborelli $
+ * $Id$
  */
 
 /* TODO: Override set_extra_widget */
@@ -39,7 +39,6 @@
 
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
-#include <libgnomevfs/gnome-vfs-mime-utils.h>
 
 #include "gedit-file-chooser-dialog.h"
 #include "gedit-encodings-option-menu.h"
@@ -134,24 +133,29 @@ filter_changed (GeditFileChooserDialog *dialog,
 		gpointer		data)
 {
 	GtkFileFilter *filter;
-	const gchar *name;
-	gint id = 0;
 
 	if (!gedit_prefs_manager_active_file_filter_can_set ())
 		return;
 
 	filter = gtk_file_chooser_get_filter (GTK_FILE_CHOOSER (dialog));
-	name = gtk_file_filter_get_name (filter);
-	g_return_if_fail (name != NULL);
+	if (filter != NULL)
+	{
+		const gchar *name;
+		gint id = 0;
 
-	if (strcmp (name, ALL_TEXT_FILES) == 0)
-		id = 1;
+		name = gtk_file_filter_get_name (filter);
+		g_return_if_fail (name != NULL);
 
-	gedit_debug_message (DEBUG_COMMANDS, "Active filter: %s (%d)", name, id);
+		if (strcmp (name, ALL_TEXT_FILES) == 0)
+			id = 1;
 
-	gedit_prefs_manager_set_active_file_filter (id);
+		gedit_debug_message (DEBUG_COMMANDS, "Active filter: %s (%d)", name, id);
+
+		gedit_prefs_manager_set_active_file_filter (id);
+	}
 }
 
+/* FIXME: use globs too - Paolo (Aug. 27, 2007) */
 static gboolean
 all_text_files_filter (const GtkFileFilterInfo *filter_info,
 		       gpointer                 data)
@@ -162,19 +166,20 @@ all_text_files_filter (const GtkFileFilterInfo *filter_info,
 	if (known_mime_types == NULL)
 	{
 		GtkSourceLanguageManager *lm;
-		GSList *languages;
-		GSList *l;
+		const gchar * const *languages;
 
 		lm = gedit_get_language_manager ();
-		languages = gtk_source_language_manager_list_languages (lm);
+		languages = gtk_source_language_manager_get_language_ids (lm);
 
-		for (l = languages; l != NULL; l = l->next)
+		while ((languages != NULL) && (*languages != NULL))
 		{
 			gchar **mime_types;
 			gint i;
 			GtkSourceLanguage *lang;
 
-			lang = l->data;
+			lang = gtk_source_language_manager_get_language (lm, *languages);
+			g_return_val_if_fail (GTK_IS_SOURCE_LANGUAGE (lang), FALSE);
+			++languages;
 
 			mime_types = gtk_source_language_get_mime_types (lang);
 			if (mime_types == NULL)
@@ -182,12 +187,7 @@ all_text_files_filter (const GtkFileFilterInfo *filter_info,
 
 			for (i = 0; mime_types[i] != NULL; i++)
 			{
-				GnomeVFSMimeEquivalence res;
-
-				res = gnome_vfs_mime_type_get_equivalence (mime_types[i],
-									   "text/plain");
-
-				if (res == GNOME_VFS_MIME_UNRELATED)
+				if (!g_content_type_is_a (mime_types[i], "text/plain"))
 				{
 					gedit_debug_message (DEBUG_COMMANDS,
 							     "Mime-type %s is not related to text/plain",
@@ -201,8 +201,6 @@ all_text_files_filter (const GtkFileFilterInfo *filter_info,
 			g_strfreev (mime_types);
 		}
 
-		g_slist_free (languages);
-
 		/* known_mime_types always has "text/plain" as first item" */
 		known_mime_types = g_slist_prepend (known_mime_types, g_strdup ("text/plain"));
 	}
@@ -226,11 +224,7 @@ all_text_files_filter (const GtkFileFilterInfo *filter_info,
 	mime_types = known_mime_types;
 	while (mime_types != NULL)
 	{
-		GnomeVFSMimeEquivalence res;
-		res = gnome_vfs_mime_type_get_equivalence (filter_info->mime_type,
-							   (const gchar*)mime_types->data);
-
-		if (res != GNOME_VFS_MIME_UNRELATED)
+		if (g_content_type_is_a (filter_info->mime_type, (const gchar*)mime_types->data))
 			return TRUE;
 
 		mime_types = g_slist_next (mime_types);
