@@ -155,16 +155,17 @@ static const GtkToggleActionEntry gedit_always_sensitive_toggle_menu_entries[] =
 	{ "ViewStatusbar", NULL, N_("_Statusbar"), NULL,
 	  N_("Show or hide the statusbar in the current window"),
 	  G_CALLBACK (_gedit_cmd_view_show_statusbar), TRUE },
-	{ "ViewSidePane", NULL, N_("Side _Pane"), "F9",
-	  N_("Show or hide the side pane in the current window"),
-	  G_CALLBACK (_gedit_cmd_view_show_side_pane), FALSE },
 	{ "ViewFullscreen", GTK_STOCK_FULLSCREEN, NULL, "F11",
 	  N_("Edit text at fullscreen"),
 	  G_CALLBACK (_gedit_cmd_view_toggle_fullscreen_mode), FALSE }
 };
 
-static const GtkToggleActionEntry gedit_toggle_menu_entries[] =
+/* separate group, should be always sensitive except when there are no panes */
+static const GtkToggleActionEntry gedit_panes_toggle_menu_entries[] =
 {
+	{ "ViewSidePane", NULL, N_("Side _Pane"), "F9",
+	  N_("Show or hide the side pane in the current window"),
+	  G_CALLBACK (_gedit_cmd_view_show_side_pane), FALSE },
 	{ "ViewBottomPane", NULL, N_("_Bottom Pane"), "<control>F9",
 	  N_("Show or hide the bottom pane in the current window"),
 	  G_CALLBACK (_gedit_cmd_view_show_bottom_pane), FALSE }
